==> nextcloud-app-mail-5.5.11-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/eo.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Enkorpiga mesaĝo %s",
    "Important" : "Grava",
    "Work" : "Laboro",
    "Personal" : "Persona",
    "Later" : "Poste",
    "Mail" : "Retpoŝtilo",
    "Mails" : "Retpoŝtoj",
    "💌 A mail app for Nextcloud" : "Poŝtprogrameto por Nextcloud",
    "Connecting" : "Konektante",
    "Save" : "Konservi",
    "Connect" : "Konekti",
    "Password required" : "Pasvorto bezonata",
    "Auto" : "Aŭtomate",
    "Name" : "Nomo",
    "Password" : "Pasvorto",
    "Manual" : "Manlibro",
    "IMAP Settings" : "IMAP-agordoj",
    "IMAP Host" : "IMAP-gastigo",
    "IMAP Security" : "IMAP-sekureco",
    "None" : "Nenio",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-pordo",
    "IMAP User" : "IMAP-uzanto",
    "IMAP Password" : "IMAP-pasvorto",
    "SMTP Settings" : "SMTP-agordoj",
    "SMTP Host" : "SMTP-gastigo",
    "SMTP Security" : "SMTP-sekureco",
    "SMTP Port" : "SMTP-pordo",
    "SMTP User" : "SMTP-uzanto",
    "SMTP Password" : "SMTP-pasvorto",
    "Account settings" : "Kontaj agordoj",
    "Signature" : "Subskribo",
    "A signature is added to the text of new messages and replies." : "Subskribo aldonus al la teksto de novaj mesaĝoj kaj respondoj.",
    "Writing mode" : "Skribreĝimo",
    "Preferred writing mode for new messages and replies." : "Prefera skribreĝimo por novaj mesaĝoj kaj respondoj.",
    "Mail server" : "Retpoŝtoservilo",
    "Go back" : "Reveni",
    "Change name" : "Ŝanĝi nomon",
    "Email address" : "Retpoŝtadreso",
    "Cancel" : "Nuligi",
    "General" : "Ĝenerala",
    "Add mail account" : "Aldoni retpoŝtan konton",
    "Newest first" : "Pli novaj unue",
    "Register" : "Registriĝi",
    "Security" : "Sekurigo",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Compose new message" : "Krei novan mesaĝon",
    "Newer message" : "Pli nova mesaĝo",
    "Older message" : "Pli malnova mesaĝo",
    "Toggle star" : "Baskuligi stelon",
    "Toggle unread" : "Baskuligi legostaton",
    "Archive" : "Arĥivujo",
    "Delete" : "Forigi",
    "Search" : "Serĉi",
    "Send" : "Sendi",
    "Refresh" : "Aktualigi",
    "Ok" : "Bone",
    "From" : "De",
    "Select account" : "Elekti konton",
    "To" : "Al",
    "Contact or email address …" : "Kontakto aŭ retpoŝtadreso …",
    "Subject" : "Temo",
    "Subject …" : "Temo …",
    "This message came from a noreply address so your reply will probably not be read." : "Ĉi tiu mesaĝo venis al neresponda-adreso, do via respondo probable ne legus.",
    "Write message …" : "Verku mesaĝon …",
    "Saving draft …" : "Konservado de malneto...",
    "Draft saved" : "Malneto konservita",
    "Enable formatting" : "Ebligi formatado",
    "Upload attachment" : "Alŝuti kunsendaĵon",
    "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
    "Enter a date" : "Entajpu daton",
    "Choose" : "Elekti",
    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
    "Confirm" : "Konfirmi",
    "Plain text" : "Ebenaĵa teksto",
    "No messages in this folder" : "Neniu mesaĝo en tiu dosierujo",
    "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
    "Unfavorite" : "Malpliŝatati",
    "Favorite" : "Pliŝatati",
    "Read" : "Legi",
    "Edit tags" : "Redakti etikedojn",
    "More actions" : "Pliaj agoj",
    "Back" : "Antaŭen",
    "Report this bug" : "Raporti tiun problemon",
    "Could not create event" : "Ne eblis krei okazaĵon",
    "All day" : "Tuttage",
    "Attendees" : "Ĉeestontoj",
    "Description" : "Priskribo",
    "Create" : "Krei",
    "Select" : "Elekti",
    "Comment" : "Komento",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Remove" : "Forigi",
    "email" : "retpoŝtadreso",
    "Today" : "Hodiaŭ",
    "Choose target folder" : "Elekti celan dosierujon",
    "Other" : "Alia",
    "Forward" : "Antaŭen",
    "Translate" : "Traduku",
    "Unnamed" : "Nenomita",
    "Embedded message" : "Enkorpiga mesaĝo",
    "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
    "Import into calendar" : "Importi en kalendaron",
    "Download attachment" : "Elŝuti kunsendaĵon",
    "Save to Files" : "Konservi en „Dosieroj“",
    "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
    "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
    "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
    "Move" : "Movi",
    "Remove account" : "Forigi konton",
    "Add folder" : "Aldoni dosierujon",
    "Folder name" : "Dosierujnomo",
    "Saving" : "Konservado",
    "Move down" : "Movi malsupren",
    "Show all folders" : "Montri ĉiujn dosierujojn",
    "Collapse folders" : "Maletendi dosierujojn",
    "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
    "Loading …" : "Ŝargas …",
    "Mark all as read" : "Marki ĉion kiel legita",
    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
    "Add subfolder" : "Aldoni subdosierujon",
    "Rename" : "Alinomi",
    "Clear cache" : "Forviŝi la kaŝmemoron",
    "New message" : "Nova mesaĝo",
    "Reply" : "Respondi",
    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
    "Retry" : "Reprovi",
    "Message" : "Mesaĝo",
    "Copy to clipboard" : "Kopii tondejen",
    "Add" : "Aldoni",
    "Show less" : "Montri malpli",
    "Show more" : "Montri pli",
    "Clear" : "Viŝi",
    "Close" : "Malfermi",
    "Date" : "Date",
    "Tags" : "Etikedoj",
    "Select tags" : "Elekti etikedojn",
    "Last 7 days" : "Lastaj 7 tagoj",
    "Custom" : "Propra",
    "Signature …" : "Subskribo …",
    "Save signature" : "Konservi subskribon",
    "Delete tag" : "Forigi etikedon",
    "Tag already exists" : "La etikedo jam ekzistas",
    "Not found" : "Ne trovita",
    "Reply to sender only" : "Respondi nur al sendinto",
    "Untitled event" : "Sentitola okazaĵo",
    "Import into {calendar}" : "Importi en {calendar}",
    "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flugo {flightNr} de {depAirport} al {arrAirport}",
    "Airplane" : "Aviadilo",
    "Reservation {id}" : "Rezervejo {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
    "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
    "Train" : "Trajno",
    "Recipient" : "Ricevonto",
    "Help" : "Helpo",
    "matches" : "kongruas kun",
    "Actions" : "Agoj",
    "Priority" : "Prioritato",
    "delete" : "forigi",
    "Edit" : "Modifi",
    "Mail app" : "Retpoŝtprogrameto",
    "Reset" : "Restarigi",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "Email: {email}" : "Retpoŝto: {email}",
    "IMAP" : "IMAP",
    "User" : "Uzanto",
    "Host" : "Gastigo",
    "Port" : "Pordo",
    "SMTP" : "SMTP",
    "E-mail address" : "Retpoŝtadreso",
    "Valid until" : "Valida ĝis",
    "Certificate" : "Atestilo",
    "Submit" : "Sendi",
    "Group" : "Grupo",
    "Shared" : "Kunhavigita",
    "Shares" : "Kunhavoj",
    "Account connected" : "Konto konektita",
    "Connect your mail account" : "Konekti vian retpoŝtan konton",
    "All" : "Ĉiuj",
    "Drafts" : "Malnetujo",
    "Favorites" : "Pliŝataĵoj",
    "All inboxes" : "Ĉiuj ricevujoj",
    "Inbox" : "Ricevujo",
    "Junk" : "Trudmesaĝujo",
    "Sent" : "Senditujo",
    "Trash" : "Rubujo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mesaĝo\nel {from}","%n novaj mesaĝoj \nel {from}"],
    "Nextcloud Mail" : "Nextcloud-retpoŝtilo",
    "Could not load {tag}{name}{endtag}" : "Ne eblis ŝargi {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Problemo okazis dum ŝargi {tag}{name}{endtag}",
    "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
    "Could not load the desired message" : "Ne eblis ŝargi la deziratan mesaĝon",
    "Could not load the message" : "Ne eblis ŝargi la mesaĝon",
    "Error loading message" : "Eraris ŝargi mesaĝon",
    "Forwarding to %s" : "Plusendi al %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
    "Redirect" : "Alidirekto",
    "The link leads to %s" : "La ligilo iras al %s",
    "Continue to %s" : "Daŭrigi al %s",
    "Accounts" : "Kontoj",
    "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
    "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.5.14-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/eo.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Enkorpiga mesaĝo %s",
    "Important" : "Grava",
    "Work" : "Laboro",
    "Personal" : "Persona",
    "Later" : "Poste",
    "Mail" : "Retpoŝtilo",
    "Mails" : "Retpoŝtoj",
    "💌 A mail app for Nextcloud" : "Poŝtprogrameto por Nextcloud",
    "Connecting" : "Konektante",
    "Save" : "Konservi",
    "Connect" : "Konekti",
    "Password required" : "Pasvorto bezonata",
    "Auto" : "Aŭtomate",
    "Name" : "Nomo",
    "Password" : "Pasvorto",
    "Manual" : "Manlibro",
    "IMAP Settings" : "IMAP-agordoj",
    "IMAP Host" : "IMAP-gastigo",
    "IMAP Security" : "IMAP-sekureco",
    "None" : "Nenio",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-pordo",
    "IMAP User" : "IMAP-uzanto",
    "IMAP Password" : "IMAP-pasvorto",
    "SMTP Settings" : "SMTP-agordoj",
    "SMTP Host" : "SMTP-gastigo",
    "SMTP Security" : "SMTP-sekureco",
    "SMTP Port" : "SMTP-pordo",
    "SMTP User" : "SMTP-uzanto",
    "SMTP Password" : "SMTP-pasvorto",
    "Account settings" : "Kontaj agordoj",
    "Signature" : "Subskribo",
    "A signature is added to the text of new messages and replies." : "Subskribo aldonus al la teksto de novaj mesaĝoj kaj respondoj.",
    "Writing mode" : "Skribreĝimo",
    "Preferred writing mode for new messages and replies." : "Prefera skribreĝimo por novaj mesaĝoj kaj respondoj.",
    "Mail server" : "Retpoŝtoservilo",
    "Go back" : "Reveni",
    "Change name" : "Ŝanĝi nomon",
    "Email address" : "Retpoŝtadreso",
    "Cancel" : "Nuligi",
    "General" : "Ĝenerala",
    "Add mail account" : "Aldoni retpoŝtan konton",
    "Newest first" : "Pli novaj unue",
    "Oldest first" : "Malpli novaj unue",
    "Register" : "Registriĝi",
    "Security" : "Sekurigo",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Compose new message" : "Krei novan mesaĝon",
    "Newer message" : "Pli nova mesaĝo",
    "Older message" : "Pli malnova mesaĝo",
    "Toggle star" : "Baskuligi stelon",
    "Toggle unread" : "Baskuligi legostaton",
    "Archive" : "Arĥivujo",
    "Delete" : "Forigi",
    "Search" : "Serĉi",
    "Send" : "Sendi",
    "Refresh" : "Aktualigi",
    "Ok" : "Bone",
    "From" : "De",
    "Select account" : "Elekti konton",
    "To" : "Al",
    "Subject" : "Temo",
    "This message came from a noreply address so your reply will probably not be read." : "Ĉi tiu mesaĝo venis al neresponda-adreso, do via respondo probable ne legus.",
    "Draft saved" : "Malneto konservita",
    "Enable formatting" : "Ebligi formatado",
    "Upload attachment" : "Alŝuti kunsendaĵon",
    "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
    "Enter a date" : "Entajpu daton",
    "Choose" : "Elekti",
    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
    "Confirm" : "Konfirmi",
    "Plain text" : "Ebenaĵa teksto",
    "No messages in this folder" : "Neniu mesaĝo en tiu dosierujo",
    "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
    "Unfavorite" : "Malpliŝatati",
    "Favorite" : "Pliŝatati",
    "Read" : "Legi",
    "Edit tags" : "Redakti etikedojn",
    "More actions" : "Pliaj agoj",
    "Back" : "Antaŭen",
    "Report this bug" : "Raporti tiun problemon",
    "Could not create event" : "Ne eblis krei okazaĵon",
    "All day" : "Tuttage",
    "Attendees" : "Ĉeestontoj",
    "Description" : "Priskribo",
    "Create" : "Krei",
    "Select" : "Elekti",
    "Comment" : "Komento",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Remove" : "Forigi",
    "email" : "retpoŝtadreso",
    "Today" : "Hodiaŭ",
    "Choose target folder" : "Elekti celan dosierujon",
    "Other" : "Alia",
    "Forward" : "Antaŭen",
    "Translate" : "Traduku",
    "Unnamed" : "Nenomita",
    "Embedded message" : "Enkorpiga mesaĝo",
    "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
    "Import into calendar" : "Importi en kalendaron",
    "Download attachment" : "Elŝuti kunsendaĵon",
    "Save to Files" : "Konservi en „Dosieroj“",
    "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
    "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
    "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
    "Move" : "Movi",
    "Remove account" : "Forigi konton",
    "Add folder" : "Aldoni dosierujon",
    "Folder name" : "Dosierujnomo",
    "Saving" : "Konservado",
    "Move down" : "Movi malsupren",
    "Show all folders" : "Montri ĉiujn dosierujojn",
    "Collapse folders" : "Maletendi dosierujojn",
    "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
    "Mark all as read" : "Marki ĉion kiel legita",
    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
    "Add subfolder" : "Aldoni subdosierujon",
    "Rename" : "Alinomi",
    "Clear cache" : "Forviŝi la kaŝmemoron",
    "New message" : "Nova mesaĝo",
    "Reply" : "Respondi",
    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
    "Retry" : "Reprovi",
    "Message" : "Mesaĝo",
    "Copy to clipboard" : "Kopii tondejen",
    "Add" : "Aldoni",
    "Show less" : "Montri malpli",
    "Show more" : "Montri pli",
    "Clear" : "Viŝi",
    "Close" : "Malfermi",
    "Date" : "Date",
    "Tags" : "Etikedoj",
    "Select tags" : "Elekti etikedojn",
    "Last 7 days" : "Lastaj 7 tagoj",
    "Custom" : "Propra",
    "Save signature" : "Konservi subskribon",
    "Delete tag" : "Forigi etikedon",
    "Tag already exists" : "La etikedo jam ekzistas",
    "Not found" : "Ne trovita",
    "Reply to sender only" : "Respondi nur al sendinto",
    "Untitled event" : "Sentitola okazaĵo",
    "Import into {calendar}" : "Importi en {calendar}",
    "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flugo {flightNr} de {depAirport} al {arrAirport}",
    "Airplane" : "Aviadilo",
    "Reservation {id}" : "Rezervejo {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
    "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
    "Train" : "Trajno",
    "Recipient" : "Ricevonto",
    "Help" : "Helpo",
    "matches" : "kongruas kun",
    "Actions" : "Agoj",
    "Priority" : "Prioritato",
    "delete" : "forigi",
    "Edit" : "Modifi",
    "Mail app" : "Retpoŝtprogrameto",
    "Reset" : "Restarigi",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "Email: {email}" : "Retpoŝto: {email}",
    "IMAP" : "IMAP",
    "User" : "Uzanto",
    "Host" : "Gastigo",
    "Port" : "Pordo",
    "SMTP" : "SMTP",
    "E-mail address" : "Retpoŝtadreso",
    "Valid until" : "Valida ĝis",
    "Certificate" : "Atestilo",
    "Submit" : "Sendi",
    "Group" : "Grupo",
    "Shared" : "Kunhavigita",
    "Shares" : "Kunhavoj",
    "Account connected" : "Konto konektita",
    "Connect your mail account" : "Konekti vian retpoŝtan konton",
    "All" : "Ĉiuj",
    "Drafts" : "Malnetujo",
    "Favorites" : "Pliŝataĵoj",
    "All inboxes" : "Ĉiuj ricevujoj",
    "Inbox" : "Ricevujo",
    "Junk" : "Trudmesaĝujo",
    "Sent" : "Senditujo",
    "Trash" : "Rubujo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mesaĝo\nel {from}","%n novaj mesaĝoj \nel {from}"],
    "Nextcloud Mail" : "Nextcloud-retpoŝtilo",
    "Could not load {tag}{name}{endtag}" : "Ne eblis ŝargi {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Problemo okazis dum ŝargi {tag}{name}{endtag}",
    "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
    "Could not load the desired message" : "Ne eblis ŝargi la deziratan mesaĝon",
    "Could not load the message" : "Ne eblis ŝargi la mesaĝon",
    "Error loading message" : "Eraris ŝargi mesaĝon",
    "Forwarding to %s" : "Plusendi al %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
    "Redirect" : "Alidirekto",
    "The link leads to %s" : "La ligilo iras al %s",
    "Continue to %s" : "Daŭrigi al %s",
    "Accounts" : "Kontoj",
    "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
    "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj",
    "Contact or email address …" : "Kontakto aŭ retpoŝtadreso …",
    "Subject …" : "Temo …",
    "Write message …" : "Verku mesaĝon …",
    "Saving draft …" : "Konservado de malneto...",
    "Loading …" : "Ŝargas …",
    "Signature …" : "Subskribo …"
},
"nplurals=2; plural=(n != 1);");
